# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Ellipse.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_Shape_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Roi' not in _M_omero.model.__dict__:
    _M_omero.model._t_Roi = IcePy.declareClass('::omero::model::Roi')
    _M_omero.model._t_RoiPrx = IcePy.declareProxy('::omero::model::Roi')

if 'AffineTransform' not in _M_omero.model.__dict__:
    _M_omero.model._t_AffineTransform = IcePy.declareClass('::omero::model::AffineTransform')
    _M_omero.model._t_AffineTransformPrx = IcePy.declareProxy('::omero::model::AffineTransform')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'ShapeAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ShapeAnnotationLink = IcePy.declareClass('::omero::model::ShapeAnnotationLink')
    _M_omero.model._t_ShapeAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ShapeAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'Ellipse' not in _M_omero.model.__dict__:
    _M_omero.model.Ellipse = Ice.createTempClass()
    class Ellipse(_M_omero.model.Shape):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _theZ=None, _theT=None, _theC=None, _roi=None, _locked=None, _transform=None, _fillColor=None, _fillRule=None, _strokeColor=None, _strokeDashArray=None, _strokeWidth=None, _fontFamily=None, _fontSize=None, _fontStyle=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _x=None, _y=None, _radiusX=None, _radiusY=None, _textValue=None):
            if Ice.getType(self) == _M_omero.model.Ellipse:
                raise RuntimeError('omero.model.Ellipse is an abstract class')
            _M_omero.model.Shape.__init__(self, _id, _details, _loaded, _version, _theZ, _theT, _theC, _roi, _locked, _transform, _fillColor, _fillRule, _strokeColor, _strokeDashArray, _strokeWidth, _fontFamily, _fontSize, _fontStyle, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._x = _x
            self._y = _y
            self._radiusX = _radiusX
            self._radiusY = _radiusY
            self._textValue = _textValue

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Ellipse', '::omero::model::IObject', '::omero::model::Shape')

        def ice_id(self, current=None):
            return '::omero::model::Ellipse'

        def ice_staticId():
            return '::omero::model::Ellipse'
        ice_staticId = staticmethod(ice_staticId)

        def getX(self, current=None):
            pass

        def setX(self, theX, current=None):
            pass

        def getY(self, current=None):
            pass

        def setY(self, theY, current=None):
            pass

        def getRadiusX(self, current=None):
            pass

        def setRadiusX(self, theRadiusX, current=None):
            pass

        def getRadiusY(self, current=None):
            pass

        def setRadiusY(self, theRadiusY, current=None):
            pass

        def getTextValue(self, current=None):
            pass

        def setTextValue(self, theTextValue, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Ellipse)

        __repr__ = __str__

    _M_omero.model.EllipsePrx = Ice.createTempClass()
    class EllipsePrx(_M_omero.model.ShapePrx):

        def getX(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getX.invoke(self, ((), _ctx))

        def begin_getX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getX(self, _r):
            return _M_omero.model.Ellipse._op_getX.end(self, _r)

        def setX(self, theX, _ctx=None):
            return _M_omero.model.Ellipse._op_setX.invoke(self, ((theX, ), _ctx))

        def begin_setX(self, theX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setX.begin(self, ((theX, ), _response, _ex, _sent, _ctx))

        def end_setX(self, _r):
            return _M_omero.model.Ellipse._op_setX.end(self, _r)

        def getY(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getY.invoke(self, ((), _ctx))

        def begin_getY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getY(self, _r):
            return _M_omero.model.Ellipse._op_getY.end(self, _r)

        def setY(self, theY, _ctx=None):
            return _M_omero.model.Ellipse._op_setY.invoke(self, ((theY, ), _ctx))

        def begin_setY(self, theY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setY.begin(self, ((theY, ), _response, _ex, _sent, _ctx))

        def end_setY(self, _r):
            return _M_omero.model.Ellipse._op_setY.end(self, _r)

        def getRadiusX(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusX.invoke(self, ((), _ctx))

        def begin_getRadiusX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRadiusX(self, _r):
            return _M_omero.model.Ellipse._op_getRadiusX.end(self, _r)

        def setRadiusX(self, theRadiusX, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusX.invoke(self, ((theRadiusX, ), _ctx))

        def begin_setRadiusX(self, theRadiusX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusX.begin(self, ((theRadiusX, ), _response, _ex, _sent, _ctx))

        def end_setRadiusX(self, _r):
            return _M_omero.model.Ellipse._op_setRadiusX.end(self, _r)

        def getRadiusY(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusY.invoke(self, ((), _ctx))

        def begin_getRadiusY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRadiusY(self, _r):
            return _M_omero.model.Ellipse._op_getRadiusY.end(self, _r)

        def setRadiusY(self, theRadiusY, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusY.invoke(self, ((theRadiusY, ), _ctx))

        def begin_setRadiusY(self, theRadiusY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusY.begin(self, ((theRadiusY, ), _response, _ex, _sent, _ctx))

        def end_setRadiusY(self, _r):
            return _M_omero.model.Ellipse._op_setRadiusY.end(self, _r)

        def getTextValue(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getTextValue.invoke(self, ((), _ctx))

        def begin_getTextValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getTextValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTextValue(self, _r):
            return _M_omero.model.Ellipse._op_getTextValue.end(self, _r)

        def setTextValue(self, theTextValue, _ctx=None):
            return _M_omero.model.Ellipse._op_setTextValue.invoke(self, ((theTextValue, ), _ctx))

        def begin_setTextValue(self, theTextValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setTextValue.begin(self, ((theTextValue, ), _response, _ex, _sent, _ctx))

        def end_setTextValue(self, _r):
            return _M_omero.model.Ellipse._op_setTextValue.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.EllipsePrx.ice_checkedCast(proxy, '::omero::model::Ellipse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.EllipsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Ellipse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_EllipsePrx = IcePy.defineProxy('::omero::model::Ellipse', EllipsePrx)

    _M_omero.model._t_Ellipse = IcePy.declareClass('::omero::model::Ellipse')

    _M_omero.model._t_Ellipse = IcePy.defineClass('::omero::model::Ellipse', Ellipse, -1, (), True, False, _M_omero.model._t_Shape, (), (
        ('_x', (), _M_omero._t_RDouble, False, 0),
        ('_y', (), _M_omero._t_RDouble, False, 0),
        ('_radiusX', (), _M_omero._t_RDouble, False, 0),
        ('_radiusY', (), _M_omero._t_RDouble, False, 0),
        ('_textValue', (), _M_omero._t_RString, False, 0)
    ))
    Ellipse._ice_type = _M_omero.model._t_Ellipse

    Ellipse._op_getX = IcePy.Operation('getX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setX = IcePy.Operation('setX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getY = IcePy.Operation('getY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setY = IcePy.Operation('setY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getRadiusX = IcePy.Operation('getRadiusX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setRadiusX = IcePy.Operation('setRadiusX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getRadiusY = IcePy.Operation('getRadiusY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setRadiusY = IcePy.Operation('setRadiusY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getTextValue = IcePy.Operation('getTextValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Ellipse._op_setTextValue = IcePy.Operation('setTextValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Ellipse = Ellipse
    del Ellipse

    _M_omero.model.EllipsePrx = EllipsePrx
    del EllipsePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 
# Copyright 2007-2016 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
upload plugin

Plugin read by omero.cli.Cli during initialization. The method(s)
defined here will be added to the Cli class for later use.
"""

import sys
import re
import os
import warnings
import mimetypes

from omero.cli import BaseControl, CLI
import omero_ext.path as path

try:
    import hashlib
    hash_sha1 = hashlib.sha1
except:
    import sha
    hash_sha1 = sha.new

HELP = """Upload local files to the OMERO server"""
RE = re.compile(r"\s*upload\s*")
UNKNOWN = 'type/unknown'


class UploadControl(BaseControl):

    def _complete(self, text, line, begidx, endidx):
        """
        Returns a file after "upload" and otherwise delegates to the
        BaseControl
        """
        m = RE.match(line)
        if m:
            return self._complete_file(RE.sub('', line))
        else:
            return BaseControl._complete(self, text, line, begidx, endidx)

    def _configure(self, parser):
        parser.add_argument("file", nargs="+")
        parser.set_defaults(func=self.upload)
        parser.add_login_arguments()

    def upload(self, args):
        self.ctx.err(
            "This module is deprecated as of OMERO 5.5.0. Use the module"
            " available from https://pypi.org/project/omero-upload/"
            " instead.", DeprecationWarning)
        client = self.ctx.conn(args)
        objIds = []
        for file in args.file:
            if not path.path(file).exists():
                self.ctx.die(500, "File: %s does not exist" % file)
        for file in args.file:
            omero_format = UNKNOWN
            if(mimetypes.guess_type(file) != (None, None)):
                omero_format = mimetypes.guess_type(file)[0]
            obj = client.upload(file, type=omero_format)
            objIds.append(obj.id.val)
            self.ctx.set("last.upload.id", obj.id.val)

        objIds = self._order_and_range_ids(objIds)
        self.ctx.out("OriginalFile:%s" % objIds)

try:
    if "OMERO_NO_DEPRECATED_PLUGINS" not in os.environ:
        warnings.warn(
            "This plugin is deprecated as of OMERO 5.5.0. Use the upload"
            " CLI plugin available from"
            " https://pypi.org/project/omero-upload/ instead.",
            DeprecationWarning)
        register("upload", UploadControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("upload", UploadControl, HELP)
        cli.invoke(sys.argv[1:])



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `IObject.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_RTypes_ice
import omero_ModelF_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'IObject' not in _M_omero.model.__dict__:
    _M_omero.model.IObject = Ice.createTempClass()
    class IObject(Ice.Object):
        """
        Base class of all model types. On the
        server, the interface ome.model.IObject
        unifies the model. In Ice, interfaces have
        a more remote connotation.
        Members:
        id -- The database id for this entity. Of RLong value
        so that transient entities can have a null id.
        details -- Internal details (permissions, owner, etc.) for
        this entity. All entities have Details, and even
        a newly created object will have a non-null
        Details instance. (In the OMERO provided mapping!)
        loaded -- An unloaded object contains no state other than id. An
        exception will be raised if any field other than id is
        accessed via the OMERO-generated methods. Unloaded objects
        are useful as pointers or proxies to server-side state.
        """
        def __init__(self, _id=None, _details=None, _loaded=False):
            if Ice.getType(self) == _M_omero.model.IObject:
                raise RuntimeError('omero.model.IObject is an abstract class')
            self._id = _id
            self._details = _details
            self._loaded = _loaded

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::IObject'

        def ice_staticId():
            return '::omero::model::IObject'
        ice_staticId = staticmethod(ice_staticId)

        def getId(self, current=None):
            pass

        def setId(self, id, current=None):
            pass

        def getDetails(self, current=None):
            pass

        def proxy(self, current=None):
            """
            Return another instance of the same type as this instance
            constructed as if by: new InstanceI( this.id.val, false );
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def shallowCopy(self, current=None):
            """
            Return another instance of the same type as this instance
            with all single-value entities unloaded and all members of
            collections also unloaded.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def unload(self, current=None):
            """
            Sets the loaded boolean to false and empties all state
            from this entity to make sending it over the network
            less costly.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def unloadCollections(self, current=None):
            """
            Each collection can also be unloaded, independently
            of the object itself. To unload all collections, use:
            object.unloadCollections();
            This is useful when it is possible that a collection no
            longer represents the state in the database, and passing the
            collections back to the server might delete some entities.
            Sending back empty collections can also save a significant
            amount of bandwidth, when working with large data graphs.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def unloadDetails(self, current=None):
            """
            As with collections, the objects under details can link
            to many other objects. Unloading the details can same
            bandwidth and simplify the server logic.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def isLoaded(self, current=None):
            """
            Tests if the objects are loaded or not. If this value is false, then
            any method call on this instance other than getId
            or setId will result in an exception.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def isGlobal(self, current=None):
            """
            Marker interface which means that special rules apply
            for both reading and writing these instances.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def isLink(self, current=None):
            """
            A link between two other types.
            Methods provided:
            - getParent()
            - getChild()
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def isMutable(self, current=None):
            """
            The server will persist changes made to these types.
            Methods provided:
            - getVersion()
            - setVersion()
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def isAnnotated(self, current=None):
            """
            Allows for the attachment of any omero.model.Annotation
            subclasses. Methods provided are:
            - linkAnnotation(Annotation)
            -
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_IObject)

        __repr__ = __str__

    _M_omero.model.IObjectPrx = Ice.createTempClass()
    class IObjectPrx(Ice.ObjectPrx):

        def getId(self, _ctx=None):
            return _M_omero.model.IObject._op_getId.invoke(self, ((), _ctx))

        def begin_getId(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_getId.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getId(self, _r):
            return _M_omero.model.IObject._op_getId.end(self, _r)

        def setId(self, id, _ctx=None):
            return _M_omero.model.IObject._op_setId.invoke(self, ((id, ), _ctx))

        def begin_setId(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_setId.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        def end_setId(self, _r):
            return _M_omero.model.IObject._op_setId.end(self, _r)

        def getDetails(self, _ctx=None):
            return _M_omero.model.IObject._op_getDetails.invoke(self, ((), _ctx))

        def begin_getDetails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_getDetails.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDetails(self, _r):
            return _M_omero.model.IObject._op_getDetails.end(self, _r)

        """
        Return another instance of the same type as this instance
        constructed as if by: new InstanceI( this.id.val, false );
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def proxy(self, _ctx=None):
            return _M_omero.model.IObject._op_proxy.invoke(self, ((), _ctx))

        """
        Return another instance of the same type as this instance
        constructed as if by: new InstanceI( this.id.val, false );
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_proxy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_proxy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Return another instance of the same type as this instance
        constructed as if by: new InstanceI( this.id.val, false );
        Arguments:
        """
        def end_proxy(self, _r):
            return _M_omero.model.IObject._op_proxy.end(self, _r)

        """
        Return another instance of the same type as this instance
        with all single-value entities unloaded and all members of
        collections also unloaded.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def shallowCopy(self, _ctx=None):
            return _M_omero.model.IObject._op_shallowCopy.invoke(self, ((), _ctx))

        """
        Return another instance of the same type as this instance
        with all single-value entities unloaded and all members of
        collections also unloaded.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_shallowCopy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_shallowCopy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Return another instance of the same type as this instance
        with all single-value entities unloaded and all members of
        collections also unloaded.
        Arguments:
        """
        def end_shallowCopy(self, _r):
            return _M_omero.model.IObject._op_shallowCopy.end(self, _r)

        """
        Sets the loaded boolean to false and empties all state
        from this entity to make sending it over the network
        less costly.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def unload(self, _ctx=None):
            return _M_omero.model.IObject._op_unload.invoke(self, ((), _ctx))

        """
        Sets the loaded boolean to false and empties all state
        from this entity to make sending it over the network
        less costly.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_unload(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_unload.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Sets the loaded boolean to false and empties all state
        from this entity to make sending it over the network
        less costly.
        Arguments:
        """
        def end_unload(self, _r):
            return _M_omero.model.IObject._op_unload.end(self, _r)

        """
        Each collection can also be unloaded, independently
        of the object itself. To unload all collections, use:
        object.unloadCollections();
        This is useful when it is possible that a collection no
        longer represents the state in the database, and passing the
        collections back to the server might delete some entities.
        Sending back empty collections can also save a significant
        amount of bandwidth, when working with large data graphs.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def unloadCollections(self, _ctx=None):
            return _M_omero.model.IObject._op_unloadCollections.invoke(self, ((), _ctx))

        """
        Each collection can also be unloaded, independently
        of the object itself. To unload all collections, use:
        object.unloadCollections();
        This is useful when it is possible that a collection no
        longer represents the state in the database, and passing the
        collections back to the server might delete some entities.
        Sending back empty collections can also save a significant
        amount of bandwidth, when working with large data graphs.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_unloadCollections(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_unloadCollections.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Each collection can also be unloaded, independently
        of the object itself. To unload all collections, use:
        object.unloadCollections();
        This is useful when it is possible that a collection no
        longer represents the state in the database, and passing the
        collections back to the server might delete some entities.
        Sending back empty collections can also save a significant
        amount of bandwidth, when working with large data graphs.
        Arguments:
        """
        def end_unloadCollections(self, _r):
            return _M_omero.model.IObject._op_unloadCollections.end(self, _r)

        """
        As with collections, the objects under details can link
        to many other objects. Unloading the details can same
        bandwidth and simplify the server logic.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def unloadDetails(self, _ctx=None):
            return _M_omero.model.IObject._op_unloadDetails.invoke(self, ((), _ctx))

        """
        As with collections, the objects under details can link
        to many other objects. Unloading the details can same
        bandwidth and simplify the server logic.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_unloadDetails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_unloadDetails.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        As with collections, the objects under details can link
        to many other objects. Unloading the details can same
        bandwidth and simplify the server logic.
        Arguments:
        """
        def end_unloadDetails(self, _r):
            return _M_omero.model.IObject._op_unloadDetails.end(self, _r)

        """
        Tests if the objects are loaded or not. If this value is false, then
        any method call on this instance other than getId
        or setId will result in an exception.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def isLoaded(self, _ctx=None):
            return _M_omero.model.IObject._op_isLoaded.invoke(self, ((), _ctx))

        """
        Tests if the objects are loaded or not. If this value is false, then
        any method call on this instance other than getId
        or setId will result in an exception.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_isLoaded(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_isLoaded.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Tests if the objects are loaded or not. If this value is false, then
        any method call on this instance other than getId
        or setId will result in an exception.
        Arguments:
        """
        def end_isLoaded(self, _r):
            return _M_omero.model.IObject._op_isLoaded.end(self, _r)

        """
        Marker interface which means that special rules apply
        for both reading and writing these instances.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def isGlobal(self, _ctx=None):
            return _M_omero.model.IObject._op_isGlobal.invoke(self, ((), _ctx))

        """
        Marker interface which means that special rules apply
        for both reading and writing these instances.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_isGlobal(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_isGlobal.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Marker interface which means that special rules apply
        for both reading and writing these instances.
        Arguments:
        """
        def end_isGlobal(self, _r):
            return _M_omero.model.IObject._op_isGlobal.end(self, _r)

        """
        A link between two other types.
        Methods provided:
        - getParent()
        - getChild()
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def isLink(self, _ctx=None):
            return _M_omero.model.IObject._op_isLink.invoke(self, ((), _ctx))

        """
        A link between two other types.
        Methods provided:
        - getParent()
        - getChild()
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_isLink(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_isLink.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        A link between two other types.
        Methods provided:
        - getParent()
        - getChild()
        Arguments:
        """
        def end_isLink(self, _r):
            return _M_omero.model.IObject._op_isLink.end(self, _r)

        """
        The server will persist changes made to these types.
        Methods provided:
        - getVersion()
        - setVersion()
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def isMutable(self, _ctx=None):
            return _M_omero.model.IObject._op_isMutable.invoke(self, ((), _ctx))

        """
        The server will persist changes made to these types.
        Methods provided:
        - getVersion()
        - setVersion()
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_isMutable(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_isMutable.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        The server will persist changes made to these types.
        Methods provided:
        - getVersion()
        - setVersion()
        Arguments:
        """
        def end_isMutable(self, _r):
            return _M_omero.model.IObject._op_isMutable.end(self, _r)

        """
        Allows for the attachment of any omero.model.Annotation
        subclasses. Methods provided are:
        - linkAnnotation(Annotation)
        -
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def isAnnotated(self, _ctx=None):
            return _M_omero.model.IObject._op_isAnnotated.invoke(self, ((), _ctx))

        """
        Allows for the attachment of any omero.model.Annotation
        subclasses. Methods provided are:
        - linkAnnotation(Annotation)
        -
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_isAnnotated(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.IObject._op_isAnnotated.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Allows for the attachment of any omero.model.Annotation
        subclasses. Methods provided are:
        - linkAnnotation(Annotation)
        -
        Arguments:
        """
        def end_isAnnotated(self, _r):
            return _M_omero.model.IObject._op_isAnnotated.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.IObjectPrx.ice_checkedCast(proxy, '::omero::model::IObject', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.IObjectPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::IObject'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_IObjectPrx = IcePy.defineProxy('::omero::model::IObject', IObjectPrx)

    _M_omero.model._t_IObject = IcePy.declareClass('::omero::model::IObject')

    _M_omero.model._t_IObject = IcePy.defineClass('::omero::model::IObject', IObject, -1, (), True, False, None, (), (
        ('_id', (), _M_omero._t_RLong, False, 0),
        ('_details', (), _M_omero.model._t_Details, False, 0),
        ('_loaded', (), IcePy._t_bool, False, 0)
    ))
    IObject._ice_type = _M_omero.model._t_IObject

    IObject._op_getId = IcePy.Operation('getId', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RLong, False, 0), ())
    IObject._op_setId = IcePy.Operation('setId', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RLong, False, 0),), (), None, ())
    IObject._op_getDetails = IcePy.Operation('getDetails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Details, False, 0), ())
    IObject._op_proxy = IcePy.Operation('proxy', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_IObject, False, 0), ())
    IObject._op_shallowCopy = IcePy.Operation('shallowCopy', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_IObject, False, 0), ())
    IObject._op_unload = IcePy.Operation('unload', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    IObject._op_unloadCollections = IcePy.Operation('unloadCollections', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    IObject._op_unloadDetails = IcePy.Operation('unloadDetails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    IObject._op_isLoaded = IcePy.Operation('isLoaded', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_bool, False, 0), ())
    IObject._op_isGlobal = IcePy.Operation('isGlobal', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_bool, False, 0), ())
    IObject._op_isLink = IcePy.Operation('isLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_bool, False, 0), ())
    IObject._op_isMutable = IcePy.Operation('isMutable', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_bool, False, 0), ())
    IObject._op_isAnnotated = IcePy.Operation('isAnnotated', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_bool, False, 0), ())

    _M_omero.model.IObject = IObject
    del IObject

    _M_omero.model.IObjectPrx = IObjectPrx
    del IObjectPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ILdap.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ServicesF_ice
import omero_Collections_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'ILdap' not in _M_omero.api.__dict__:
    _M_omero.api.ILdap = Ice.createTempClass()
    class ILdap(_M_omero.api.ServiceInterface):
        """
        Administration interface providing access to admin-only
        functionality as well as JMX-based server access and selected user
        functions. Most methods require membership in privileged
        omero.model.ExperimenterGroup groups.
        Methods which return omero.model.Experimenter or
        omero.model.ExperimenterGroup instances fetch and load all
        related instances of omero.model.ExperimenterGroup or
        omero.model.Experimenter, respectively.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.ILdap:
                raise RuntimeError('omero.api.ILdap is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::ILdap', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::ILdap'

        def ice_staticId():
            return '::omero::api::ILdap'
        ice_staticId = staticmethod(ice_staticId)

        def searchAll_async(self, _cb, current=None):
            """
            Searches all omero.model.Experimenter list on LDAP
            for attribute objectClass = person.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def searchDnInGroups_async(self, _cb, attr, value, current=None):
            """
            Searches Distinguished Name in groups.
            Arguments:
            _cb -- The asynchronous callback object.
            attr -- Name of member attribute. Never null or empty.
            value -- User's DN which should be set on value for attribute. Never null or empty.
            current -- The Current object for the invocation.
            """
            pass

        def searchByAttribute_async(self, _cb, dn, attribute, value, current=None):
            """
            Searches all omero.model.Experimenter in LDAP for
            specified attribute.
            Arguments:
            _cb -- The asynchronous callback object.
            dn -- Distinguished Name base for search. Never null.
            attribute -- Name of attribute. Never null or empty.
            value -- Expected value of attribute. Never null or empty.
            current -- The Current object for the invocation.
            """
            pass

        def searchByAttributes_async(self, _cb, dn, attributes, values, current=None):
            """
            Searches all omero.model.Experimenter in LDAP for
            specified attributes. Attributes should be specified in
            StringSet and their values should be set in equivalent
            StringSet.
            Arguments:
            _cb -- The asynchronous callback object.
            dn -- Distinguished Name base for search. Never null.
            attributes -- Name of attribute. Never null or empty.
            values -- Expected value of attribute. Never null or empty.
            current -- The Current object for the invocation.
            """
            pass

        def searchByDN_async(self, _cb, userdn, current=None):
            """
            Searches one omero.model.Experimenter in LDAP for
            specified Distinguished Name.
            Arguments:
            _cb -- The asynchronous callback object.
            userdn -- unique Distinguished Name - string of user, Never null or empty.
            current -- The Current object for the invocation.
            """
            pass

        def findDN_async(self, _cb, username, current=None):
            """
            Searches unique Distinguished Name - string in LDAP for
            Common Name equals username. Common Name should be unique
            under the specified base. If list of cn's contains more
            then one DN will return exception.
            Arguments:
            _cb -- The asynchronous callback object.
            username -- Name of the Experimenter equals CommonName.
            current -- The Current object for the invocation.
            Throws:
            ApiUsageException -- if more then one 'cn' under the specified base.
            """
            pass

        def findGroupDN_async(self, _cb, groupname, current=None):
            """
            Looks up the DN for a group.
            Arguments:
            _cb -- The asynchronous callback object.
            groupname -- 
            current -- The Current object for the invocation.
            Throws:
            ApiUsageException -- if more then one 'cn' under the specified base.
            """
            pass

        def findExperimenter_async(self, _cb, username, current=None):
            """
            Searches Experimenter by unique Distinguished Name -
            string in LDAP for Common Name equals username. Common
            Name should be unique under the specified base. If list of
            cn's contains more then one DN will return exception.
            Arguments:
            _cb -- The asynchronous callback object.
            username -- Name of the Experimenter equals CommonName.
            current -- The Current object for the invocation.
            Throws:
            ApiUsageException -- if more then one 'cn' under the specified base.
            """
            pass

        def findGroup_async(self, _cb, groupname, current=None):
            """
            Looks up a specific omero.model.ExperimenterGroup
            in LDAP using the provided group name. It is expected that
            the group name will be unique in the searched LDAP base
            tree. If more than one group with the specified name has
            been found, an exception will be thrown.
            Arguments:
            _cb -- The asynchronous callback object.
            groupname -- 
            current -- The Current object for the invocation.
            Throws:
            ApiUsageException -- if more then one group name matches under the specified base.
            """
            pass

        def setDN_async(self, _cb, experimenterID, dn, current=None):
            pass

        def getSetting_async(self, _cb, current=None):
            """
            Gets config value from properties.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def discover_async(self, _cb, current=None):
            """
            Discovers and lists omero.model.Experimenters who
            are present in the remote LDAP server and in the local DB
            but have the ldap property set to
            false.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def discoverGroups_async(self, _cb, current=None):
            """
            Discovers and lists omero.model.ExperimenterGroups
            which are present in the remote LDAP server and in the local
            DB but have the ldap property set to
            false.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def createUser_async(self, _cb, username, current=None):
            """
            Creates an omero.model.Experimenter entry in the
            OMERO DB based on the supplied LDAP username.
            Arguments:
            _cb -- The asynchronous callback object.
            username -- 
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_ILdap)

        __repr__ = __str__

    _M_omero.api.ILdapPrx = Ice.createTempClass()
    class ILdapPrx(_M_omero.api.ServiceInterfacePrx):

        """
        Searches all omero.model.Experimenter list on LDAP
        for attribute objectClass = person.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: all Experimenter list.
        """
        def searchAll(self, _ctx=None):
            return _M_omero.api.ILdap._op_searchAll.invoke(self, ((), _ctx))

        """
        Searches all omero.model.Experimenter list on LDAP
        for attribute objectClass = person.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_searchAll(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_searchAll.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Searches all omero.model.Experimenter list on LDAP
        for attribute objectClass = person.
        Arguments:
        Returns: all Experimenter list.
        """
        def end_searchAll(self, _r):
            return _M_omero.api.ILdap._op_searchAll.end(self, _r)

        """
        Searches Distinguished Name in groups.
        Arguments:
        attr -- Name of member attribute. Never null or empty.
        value -- User's DN which should be set on value for attribute. Never null or empty.
        _ctx -- The request context for the invocation.
        Returns: List of groups which contains DN.
        """
        def searchDnInGroups(self, attr, value, _ctx=None):
            return _M_omero.api.ILdap._op_searchDnInGroups.invoke(self, ((attr, value), _ctx))

        """
        Searches Distinguished Name in groups.
        Arguments:
        attr -- Name of member attribute. Never null or empty.
        value -- User's DN which should be set on value for attribute. Never null or empty.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_searchDnInGroups(self, attr, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_searchDnInGroups.begin(self, ((attr, value), _response, _ex, _sent, _ctx))

        """
        Searches Distinguished Name in groups.
        Arguments:
        attr -- Name of member attribute. Never null or empty.
        value -- User's DN which should be set on value for attribute. Never null or empty.
        Returns: List of groups which contains DN.
        """
        def end_searchDnInGroups(self, _r):
            return _M_omero.api.ILdap._op_searchDnInGroups.end(self, _r)

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attribute.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attribute -- Name of attribute. Never null or empty.
        value -- Expected value of attribute. Never null or empty.
        _ctx -- The request context for the invocation.
        Returns: List of Experimenters.
        """
        def searchByAttribute(self, dn, attribute, value, _ctx=None):
            return _M_omero.api.ILdap._op_searchByAttribute.invoke(self, ((dn, attribute, value), _ctx))

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attribute.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attribute -- Name of attribute. Never null or empty.
        value -- Expected value of attribute. Never null or empty.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_searchByAttribute(self, dn, attribute, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_searchByAttribute.begin(self, ((dn, attribute, value), _response, _ex, _sent, _ctx))

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attribute.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attribute -- Name of attribute. Never null or empty.
        value -- Expected value of attribute. Never null or empty.
        Returns: List of Experimenters.
        """
        def end_searchByAttribute(self, _r):
            return _M_omero.api.ILdap._op_searchByAttribute.end(self, _r)

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attributes. Attributes should be specified in
        StringSet and their values should be set in equivalent
        StringSet.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attributes -- Name of attribute. Never null or empty.
        values -- Expected value of attribute. Never null or empty.
        _ctx -- The request context for the invocation.
        Returns: List of Experimenters.
        """
        def searchByAttributes(self, dn, attributes, values, _ctx=None):
            return _M_omero.api.ILdap._op_searchByAttributes.invoke(self, ((dn, attributes, values), _ctx))

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attributes. Attributes should be specified in
        StringSet and their values should be set in equivalent
        StringSet.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attributes -- Name of attribute. Never null or empty.
        values -- Expected value of attribute. Never null or empty.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_searchByAttributes(self, dn, attributes, values, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_searchByAttributes.begin(self, ((dn, attributes, values), _response, _ex, _sent, _ctx))

        """
        Searches all omero.model.Experimenter in LDAP for
        specified attributes. Attributes should be specified in
        StringSet and their values should be set in equivalent
        StringSet.
        Arguments:
        dn -- Distinguished Name base for search. Never null.
        attributes -- Name of attribute. Never null or empty.
        values -- Expected value of attribute. Never null or empty.
        Returns: List of Experimenters.
        """
        def end_searchByAttributes(self, _r):
            return _M_omero.api.ILdap._op_searchByAttributes.end(self, _r)

        """
        Searches one omero.model.Experimenter in LDAP for
        specified Distinguished Name.
        Arguments:
        userdn -- unique Distinguished Name - string of user, Never null or empty.
        _ctx -- The request context for the invocation.
        Returns: an Experimenter.
        """
        def searchByDN(self, userdn, _ctx=None):
            return _M_omero.api.ILdap._op_searchByDN.invoke(self, ((userdn, ), _ctx))

        """
        Searches one omero.model.Experimenter in LDAP for
        specified Distinguished Name.
        Arguments:
        userdn -- unique Distinguished Name - string of user, Never null or empty.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_searchByDN(self, userdn, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_searchByDN.begin(self, ((userdn, ), _response, _ex, _sent, _ctx))

        """
        Searches one omero.model.Experimenter in LDAP for
        specified Distinguished Name.
        Arguments:
        userdn -- unique Distinguished Name - string of user, Never null or empty.
        Returns: an Experimenter.
        """
        def end_searchByDN(self, _r):
            return _M_omero.api.ILdap._op_searchByDN.end(self, _r)

        """
        Searches unique Distinguished Name - string in LDAP for
        Common Name equals username. Common Name should be unique
        under the specified base. If list of cn's contains more
        then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        _ctx -- The request context for the invocation.
        Returns: a Distinguished Name. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def findDN(self, username, _ctx=None):
            return _M_omero.api.ILdap._op_findDN.invoke(self, ((username, ), _ctx))

        """
        Searches unique Distinguished Name - string in LDAP for
        Common Name equals username. Common Name should be unique
        under the specified base. If list of cn's contains more
        then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findDN(self, username, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_findDN.begin(self, ((username, ), _response, _ex, _sent, _ctx))

        """
        Searches unique Distinguished Name - string in LDAP for
        Common Name equals username. Common Name should be unique
        under the specified base. If list of cn's contains more
        then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        Returns: a Distinguished Name. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def end_findDN(self, _r):
            return _M_omero.api.ILdap._op_findDN.end(self, _r)

        """
        Looks up the DN for a group.
        Arguments:
        groupname -- 
        _ctx -- The request context for the invocation.
        Returns: a Distinguished Name. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def findGroupDN(self, groupname, _ctx=None):
            return _M_omero.api.ILdap._op_findGroupDN.invoke(self, ((groupname, ), _ctx))

        """
        Looks up the DN for a group.
        Arguments:
        groupname -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findGroupDN(self, groupname, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_findGroupDN.begin(self, ((groupname, ), _response, _ex, _sent, _ctx))

        """
        Looks up the DN for a group.
        Arguments:
        groupname -- 
        Returns: a Distinguished Name. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def end_findGroupDN(self, _r):
            return _M_omero.api.ILdap._op_findGroupDN.end(self, _r)

        """
        Searches Experimenter by unique Distinguished Name -
        string in LDAP for Common Name equals username. Common
        Name should be unique under the specified base. If list of
        cn's contains more then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        _ctx -- The request context for the invocation.
        Returns: an Experimenter. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def findExperimenter(self, username, _ctx=None):
            return _M_omero.api.ILdap._op_findExperimenter.invoke(self, ((username, ), _ctx))

        """
        Searches Experimenter by unique Distinguished Name -
        string in LDAP for Common Name equals username. Common
        Name should be unique under the specified base. If list of
        cn's contains more then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findExperimenter(self, username, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_findExperimenter.begin(self, ((username, ), _response, _ex, _sent, _ctx))

        """
        Searches Experimenter by unique Distinguished Name -
        string in LDAP for Common Name equals username. Common
        Name should be unique under the specified base. If list of
        cn's contains more then one DN will return exception.
        Arguments:
        username -- Name of the Experimenter equals CommonName.
        Returns: an Experimenter. Never null.
        Throws:
        ApiUsageException -- if more then one 'cn' under the specified base.
        """
        def end_findExperimenter(self, _r):
            return _M_omero.api.ILdap._op_findExperimenter.end(self, _r)

        """
        Looks up a specific omero.model.ExperimenterGroup
        in LDAP using the provided group name. It is expected that
        the group name will be unique in the searched LDAP base
        tree. If more than one group with the specified name has
        been found, an exception will be thrown.
        Arguments:
        groupname -- 
        _ctx -- The request context for the invocation.
        Returns: an ExperimenterGroup. Never null.
        Throws:
        ApiUsageException -- if more then one group name matches under the specified base.
        """
        def findGroup(self, groupname, _ctx=None):
            return _M_omero.api.ILdap._op_findGroup.invoke(self, ((groupname, ), _ctx))

        """
        Looks up a specific omero.model.ExperimenterGroup
        in LDAP using the provided group name. It is expected that
        the group name will be unique in the searched LDAP base
        tree. If more than one group with the specified name has
        been found, an exception will be thrown.
        Arguments:
        groupname -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findGroup(self, groupname, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_findGroup.begin(self, ((groupname, ), _response, _ex, _sent, _ctx))

        """
        Looks up a specific omero.model.ExperimenterGroup
        in LDAP using the provided group name. It is expected that
        the group name will be unique in the searched LDAP base
        tree. If more than one group with the specified name has
        been found, an exception will be thrown.
        Arguments:
        groupname -- 
        Returns: an ExperimenterGroup. Never null.
        Throws:
        ApiUsageException -- if more then one group name matches under the specified base.
        """
        def end_findGroup(self, _r):
            return _M_omero.api.ILdap._op_findGroup.end(self, _r)

        def setDN(self, experimenterID, dn, _ctx=None):
            return _M_omero.api.ILdap._op_setDN.invoke(self, ((experimenterID, dn), _ctx))

        def begin_setDN(self, experimenterID, dn, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_setDN.begin(self, ((experimenterID, dn), _response, _ex, _sent, _ctx))

        def end_setDN(self, _r):
            return _M_omero.api.ILdap._op_setDN.end(self, _r)

        """
        Gets config value from properties.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: boolean
        """
        def getSetting(self, _ctx=None):
            return _M_omero.api.ILdap._op_getSetting.invoke(self, ((), _ctx))

        """
        Gets config value from properties.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSetting(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_getSetting.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Gets config value from properties.
        Arguments:
        Returns: boolean
        """
        def end_getSetting(self, _r):
            return _M_omero.api.ILdap._op_getSetting.end(self, _r)

        """
        Discovers and lists omero.model.Experimenters who
        are present in the remote LDAP server and in the local DB
        but have the ldap property set to
        false.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: list of Experimenters.
        """
        def discover(self, _ctx=None):
            return _M_omero.api.ILdap._op_discover.invoke(self, ((), _ctx))

        """
        Discovers and lists omero.model.Experimenters who
        are present in the remote LDAP server and in the local DB
        but have the ldap property set to
        false.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_discover(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_discover.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Discovers and lists omero.model.Experimenters who
        are present in the remote LDAP server and in the local DB
        but have the ldap property set to
        false.
        Arguments:
        Returns: list of Experimenters.
        """
        def end_discover(self, _r):
            return _M_omero.api.ILdap._op_discover.end(self, _r)

        """
        Discovers and lists omero.model.ExperimenterGroups
        which are present in the remote LDAP server and in the local
        DB but have the ldap property set to
        false.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: list of ExperimenterGroups.
        """
        def discoverGroups(self, _ctx=None):
            return _M_omero.api.ILdap._op_discoverGroups.invoke(self, ((), _ctx))

        """
        Discovers and lists omero.model.ExperimenterGroups
        which are present in the remote LDAP server and in the local
        DB but have the ldap property set to
        false.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_discoverGroups(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_discoverGroups.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Discovers and lists omero.model.ExperimenterGroups
        which are present in the remote LDAP server and in the local
        DB but have the ldap property set to
        false.
        Arguments:
        Returns: list of ExperimenterGroups.
        """
        def end_discoverGroups(self, _r):
            return _M_omero.api.ILdap._op_discoverGroups.end(self, _r)

        """
        Creates an omero.model.Experimenter entry in the
        OMERO DB based on the supplied LDAP username.
        Arguments:
        username -- 
        _ctx -- The request context for the invocation.
        Returns: created Experimenter or null
        """
        def createUser(self, username, _ctx=None):
            return _M_omero.api.ILdap._op_createUser.invoke(self, ((username, ), _ctx))

        """
        Creates an omero.model.Experimenter entry in the
        OMERO DB based on the supplied LDAP username.
        Arguments:
        username -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createUser(self, username, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.ILdap._op_createUser.begin(self, ((username, ), _response, _ex, _sent, _ctx))

        """
        Creates an omero.model.Experimenter entry in the
        OMERO DB based on the supplied LDAP username.
        Arguments:
        username -- 
        Returns: created Experimenter or null
        """
        def end_createUser(self, _r):
            return _M_omero.api.ILdap._op_createUser.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.ILdapPrx.ice_checkedCast(proxy, '::omero::api::ILdap', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.ILdapPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::ILdap'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_ILdapPrx = IcePy.defineProxy('::omero::api::ILdap', ILdapPrx)

    _M_omero.api._t_ILdap = IcePy.defineClass('::omero::api::ILdap', ILdap, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    ILdap._ice_type = _M_omero.api._t_ILdap

    ILdap._op_searchAll = IcePy.Operation('searchAll', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.api._t_ExperimenterList, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_searchDnInGroups = IcePy.Operation('searchDnInGroups', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero.api._t_StringSet, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_searchByAttribute = IcePy.Operation('searchByAttribute', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_omero.api._t_ExperimenterList, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_searchByAttributes = IcePy.Operation('searchByAttributes', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero.api._t_StringSet, False, 0), ((), _M_omero.api._t_StringSet, False, 0)), (), ((), _M_omero.api._t_ExperimenterList, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_searchByDN = IcePy.Operation('searchByDN', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.model._t_Experimenter, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_findDN = IcePy.Operation('findDN', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_string, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_findGroupDN = IcePy.Operation('findGroupDN', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_string, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_findExperimenter = IcePy.Operation('findExperimenter', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.model._t_Experimenter, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_findGroup = IcePy.Operation('findGroup', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.model._t_ExperimenterGroup, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_setDN = IcePy.Operation('setDN', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero._t_RLong, False, 0), ((), IcePy._t_string, False, 0)), (), None, (_M_omero._t_ServerError,))
    ILdap._op_setDN.deprecate("setDN() is deprecated. Set the LDAP flag on model objects instead.")
    ILdap._op_getSetting = IcePy.Operation('getSetting', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), IcePy._t_bool, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_discover = IcePy.Operation('discover', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.api._t_ExperimenterList, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_discoverGroups = IcePy.Operation('discoverGroups', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.api._t_ExperimenterGroupList, False, 0), (_M_omero._t_ServerError,))
    ILdap._op_createUser = IcePy.Operation('createUser', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero.model._t_Experimenter, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.ILdap = ILdap
    del ILdap

    _M_omero.api.ILdapPrx = ILdapPrx
    del ILdapPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero
